@@ -28,6 +28,7 @@
 #'   \item Replace \code{formatnr} by \code{\link{format_nr}}
 #'   \item Replace \code{getclass} by \code{\link{get_class}}
 #'   \item Replace \code{is_numeric} by \code{\link{is_double}}
+#'   \item Replace \code{is_empty} by \code{\link{is.empty}}
 #' }
 #'
 mean_rm <- function(...) {
@@ -110,4 +111,9 @@ is_numeric <- function(...) {
   .Deprecated("is_double")
   is_double(...)
 }
+is_empty <- function(...) {
+  .Deprecated("is.empty")
+  is.empty(...)
+}
+
 NULL
