@@ -149,7 +149,7 @@ explore <- function(dataset, vars = "", byvar = "", fun = c("mean", "sd"),
 
   ## ensure factors ordered as in the (sorted) table
   if (!is.empty(byvar) && top != "byvar") {
-    for (i in byvar) tab[[i]] %<>% factor(., levels = unique(.))
+    for (i in byvar) tab[[i]] <- tab[[i]] %>% (function(x) factor(x, levels = unique(x)))
     rm(i)
   }
 
@@ -705,4 +705,4 @@ modal <- function(x, na.rm = TRUE) {
   if (na.rm) x <- na.omit(x)
   unv <- unique(x)
   unv[which.max(tabulate(match(x, unv)))]
-}
\ No newline at end of file
+}
