@@ -195,7 +195,6 @@ pre {
 ## Based on http://stackoverflow.com/a/31797947/1974918
 ## as of 12/30/2017 doesn't seem to work anymore
 knit_it_save <- function(report) {
-
   ## Read input and convert to Markdown
   md <- knitr::knit(text = report, envir = r_data)
 
@@ -235,11 +234,11 @@ knit_it_save <- function(report) {
   preserved <- htmltools::extractPreserveChunks(md)
 
   ## Render the HTML, and then restore the preserved chunks
-  markdown::markdownToHTML(
+  markdown::mark_html(
     text = preserved$value,
     header = dep_html,
     options = c("mathjax", "base64_images"),
-    stylesheet = file.path(getOption("radiant.path.data"), "app/www/bootstrap.min.css")
+    meta = list(css = file.path(getOption("radiant.path.data"), "app/www/bootstrap.min.css"))
   ) %>%
     htmltools::restorePreserveChunks(preserved$chunks) %>%
     gsub("<table>", "<table class='table table-condensed table-hover'>", .)
@@ -317,7 +316,6 @@ observeEvent(input$report_ignore, {
 
 ## Knit for report in Radiant
 knit_it <- function(report, type = "rmd") {
-
   ## may be needed on windows when text has been copy-and-pasted
   ## from a pdf
   report <- gsub("\r\n", "\n", report) %>%
@@ -387,7 +385,7 @@ knit_it <- function(report, type = "rmd") {
 
   ## sizing issue with ggplotly and knitr
   ## see https://github.com/ropensci/plotly/issues/1171
-  ## see also below unsuccesful fix setting height to 100%
+  ## see also below unsuccessful fix setting height to 100%
   # if (grepl("ggplotly\\(\\)", report)) {
   #   message("\n\nHeight of ggplotly objects may not be correct in Preview. The height will be correctly displayed in saved reports however.\n\n")
   # }
@@ -412,7 +410,7 @@ knit_it <- function(report, type = "rmd") {
 
   ## add basic styling to tables
   paste(
-    markdown::markdownToHTML(text = md, fragment.only = TRUE, stylesheet = ""),
+    markdown::mark_html(text = md, template = FALSE, meta = list(css = ""), output = FALSE),
     paste0("<script type='text/javascript' src='", getOption("radiant.mathjax.path"), "/MathJax.js?config=TeX-AMS-MML_HTMLorMML'></script>"),
     "<script>if (window.MathJax) MathJax.Hub.Typeset();</script>",
     sep = "\n"
@@ -599,8 +597,8 @@ report_save_content <- function(file, type = "rmd") {
                   "<span>
                     The working directory used by radiant (\"", getwd(), "\") is not writable. This is required to save a report.
                     To save reports, restart radiant from a writable directory. Preferaby by setting up an Rstudio
-                    project folder. See <a href='https://support.rstudio.com/hc/en-us/articles/200526207-Using-Projects' target='_blank'>
-                    https://support.rstudio.com/hc/en-us/articles/200526207-Using-Projects</a> for more information
+                    project folder. See <a href='https://support.posit.co/hc/en-us/articles/200526207-Using-Projects' target='_blank'>
+                    https://support.posit.co/hc/en-us/articles/200526207-Using-Projects</a> for more information
                   </span>"
                 )
               ),
@@ -677,7 +675,6 @@ update_report <- function(inp_main = "", fun_name = "", inp_out = list("", ""),
                           cmd = "", pre_cmd = "result <- ", post_cmd = "",
                           xcmd = "", outputs = c("summary", "plot"), inp = "result",
                           wrap, figs = TRUE, fig.width = 7, fig.height = 7) {
-
   ## determine number of characters for main command for wrapping
   if (missing(wrap)) {
     lng <- nchar(pre_cmd) + nchar(fun_name) + nchar(post_cmd) + 2
@@ -750,18 +747,20 @@ update_report <- function(inp_main = "", fun_name = "", inp_out = list("", ""),
         inp <- inp_out[[i]][[inp]]
         inp_out[[i]][inp_rep] <- NULL
       }
-      if (inp_out[i] != "" && length(inp_out[[i]]) > 0) {
-        if (sum(nchar(inp_out[[i]])) > 40L) {
-          cmd <- depr(inp_out[[i]], wrap = TRUE) %>%
-            sub("list\\(", paste0(outputs[i], "\\(\n  ", inp, ", "), .) %>%
-            paste0(cmd, "\n", .)
+      if (!is.empty(outputs[i])) {
+        if (inp_out[i] != "" && length(inp_out[[i]]) > 0) {
+          if (sum(nchar(inp_out[[i]])) > 40L) {
+            cmd <- depr(inp_out[[i]], wrap = TRUE) %>%
+              sub("list\\(", paste0(outputs[i], "\\(\n  ", inp, ", "), .) %>%
+              paste0(cmd, "\n", .)
+          } else {
+            cmd <- deparse(inp_out[[i]], control = dctrl, width.cutoff = 500L) %>%
+              sub("list\\(", paste0(outputs[i], "\\(", inp, ", "), .) %>%
+              paste0(cmd, "\n", .)
+          }
         } else {
-          cmd <- deparse(inp_out[[i]], control = dctrl, width.cutoff = 500L) %>%
-            sub("list\\(", paste0(outputs[i], "\\(", inp, ", "), .) %>%
-            paste0(cmd, "\n", .)
+          cmd <- paste0(cmd, "\n", outputs[i], "(", inp, ")")
         }
-      } else {
-        cmd <- paste0(cmd, "\n", outputs[i], "(", inp, ")")
       }
     }
   }
@@ -848,4 +847,4 @@ update_report_fun <- function(cmd, type = "rmd", rfiles = FALSE) {
       }
     }
   })
-}
\ No newline at end of file
+}
