@@ -137,9 +137,9 @@ observeEvent(input$r_generate, {
       }
       ## get info from rstudio editor
       cnt <- rstudio_context(type = "r")
-      if (radiant.data::is_empty(cnt$path) || cnt$ext != "r") {
+      if (is.empty(cnt$path) || cnt$ext != "r") {
         rcode <- r_state$radiant_r_name
-        if (!radiant.data::is_empty(rcode)) {
+        if (!is.empty(rcode)) {
           if (file.exists(rcode)) {
             ## useful if you are not using an Rstudio project
             rstudioapi::navigateToFile(rcode)
@@ -315,7 +315,7 @@ output$r_knitted <- renderUI({
       withProgress(message = "Knitting report", value = 1, {
         if (isTRUE(input$r_generate == "To R")) {
           cnt <- rstudio_context(type = "r")
-          if (radiant.data::is_empty(cnt$path) || radiant.data::is_empty(cnt$ext, "rmd")) {
+          if (is.empty(cnt$path) || is.empty(cnt$ext, "rmd")) {
 
             ## popup to suggest user create an .Rmd file
             showModal(
@@ -342,10 +342,10 @@ output$r_knitted <- renderUI({
             }
             report <- cnt$content
           }
-        } else if (!radiant.data::is_empty(input$r_edit)) {
-          if (!radiant.data::is_empty(input$r_edit_selection, "")) {
+        } else if (!is.empty(input$r_edit)) {
+          if (!is.empty(input$r_edit_selection, "")) {
             report <- input$r_edit_selection
-          } else if (!radiant.data::is_empty(input$r_edit_hotkey$line, "") && report_r$knit_button == 0) {
+          } else if (!is.empty(input$r_edit_hotkey$line, "") && report_r$knit_button == 0) {
             report <- input$r_edit_hotkey$line
           } else {
             report <- input$r_edit
@@ -404,7 +404,7 @@ observeEvent(input$r_load, {
     )
   }
 
-  if (!inherits(path, "try-error") && !radiant.data::is_empty(path)) {
+  if (!inherits(path, "try-error") && !is.empty(path)) {
     if (pp$fext == "html") {
       ## based on https://rmarkdown.rstudio.com/r_notebook_format.html
       rmd <- try(rmarkdown::parse_html_notebook(pp$path), silent = TRUE)
@@ -436,7 +436,7 @@ observeEvent(input$r_read_files, {
     return()
   }
   path <- shinyFiles::parseFilePaths(sf_volumes, input$r_read_files)
-  if (inherits(path, "try-error") || radiant.data::is_empty(path$datapath)) {
+  if (inherits(path, "try-error") || is.empty(path$datapath)) {
     return()
   }
   ldir <- getOption("radiant.launch_dir", default = radiant.data::find_home())
@@ -444,7 +444,7 @@ observeEvent(input$r_read_files, {
 
   cmd <- read_files(path$datapath, pdir = pdir, type = "r", clipboard = FALSE, radiant = TRUE)
 
-  if (!radiant.data::is_empty(cmd)) {
+  if (!is.empty(cmd)) {
     update_report_fun(cmd, type = "r", rfiles = TRUE)
   }
 })
